@@ -939,14 +939,14 @@ def test_to_wkt_none_warning(wkt_version):
         'ORDER[3],LENGTHUNIT["metre",1,ID["EPSG",9001]]]]'
     )
     crs = CRS.from_wkt(wkt_string)
-    with pytest.warns(FutureWarning, match="CRS cannot be converted to a WKT string"):
+    with pytest.raises(CRSError, match="CRS cannot be converted to a WKT string"):
         assert crs.to_wkt(version=wkt_version) is None
 
 
 def test_to_proj4_none_warning():
     crs = CRS("EPSG:4326")
-    with patch("pyproj.crs.crs.CRS._crs") as crs_mock, pytest.warns(
-        FutureWarning, match="CRS cannot be converted to a PROJ string"
+    with patch("pyproj.crs.crs.CRS._crs") as crs_mock, pytest.raises(
+        CRSError, match="CRS cannot be converted to a PROJ string"
     ):
         crs_mock.to_proj4.return_value = None
         assert crs.to_proj4() is None
@@ -954,8 +954,8 @@ def test_to_proj4_none_warning():
 
 def test_to_json_none_warning():
     crs = CRS("EPSG:4326")
-    with patch("pyproj.crs.crs.CRS._crs") as crs_mock, pytest.warns(
-        FutureWarning, match="CRS cannot be converted to a PROJ JSON string"
+    with patch("pyproj.crs.crs.CRS._crs") as crs_mock, pytest.raises(
+        CRSError, match="CRS cannot be converted to a PROJ JSON string"
     ):
         crs_mock.to_json.return_value = None
         assert crs.to_json() is None
@@ -1235,7 +1235,7 @@ def test_from_authority__ignf():
 
 def test_ignf_authority_repr():
     assert repr(CRS.from_authority("IGNF", "ETRS89UTM28")).startswith(
-        "<Derived Projected CRS: IGNF:ETRS89UTM28>"
+        "<Projected CRS: IGNF:ETRS89UTM28>"
     )
 
 
@@ -1270,6 +1270,52 @@ def test_crs_is_exact_same__non_crs_input():
         assert not CRS(4326).is_exact_same("+init=epsg:4326")
 
 
+def test_derived_projected_crs():
+    wkt = (
+        'DERIVEDPROJCRS["derived projectedCRS",\n'
+        '    BASEPROJCRS["WGS 84 / UTM zone 31N",\n'
+        '        BASEGEOGCRS["WGS 84",\n'
+        '            DATUM["World Geodetic System 1984",\n'
+        '                ELLIPSOID["WGS 84",6378137,298.257223563,\n'
+        '                    LENGTHUNIT["metre",1]]],\n'
+        '            PRIMEM["Greenwich",0,\n'
+        '                ANGLEUNIT["degree",0.0174532925199433]]],\n'
+        '        CONVERSION["UTM zone 31N",\n'
+        '            METHOD["Transverse Mercator",\n'
+        '                ID["EPSG",9807]],\n'
+        '            PARAMETER["Latitude of natural origin",0,\n'
+        '                ANGLEUNIT["degree",0.0174532925199433],\n'
+        '                ID["EPSG",8801]],\n'
+        '            PARAMETER["Longitude of natural origin",3,\n'
+        '                ANGLEUNIT["degree",0.0174532925199433],\n'
+        '                ID["EPSG",8802]],\n'
+        '            PARAMETER["Scale factor at natural origin",0.9996,\n'
+        '                SCALEUNIT["unity",1],\n'
+        '                ID["EPSG",8805]],\n'
+        '            PARAMETER["False easting",500000,\n'
+        '                LENGTHUNIT["metre",1],\n'
+        '                ID["EPSG",8806]],\n'
+        '            PARAMETER["False northing",0,\n'
+        '                LENGTHUNIT["metre",1],\n'
+        '                ID["EPSG",8807]]]],\n'
+        '    DERIVINGCONVERSION["unnamed",\n'
+        '        METHOD["PROJ unimplemented"],\n'
+        '        PARAMETER["foo",1.0,UNIT["metre",1]]],\n'
+        "    CS[Cartesian,2],\n"
+        '        AXIS["(E)",east,\n'
+        "            ORDER[1],\n"
+        '            LENGTHUNIT["metre",1,\n'
+        '                ID["EPSG",9001]]],\n'
+        '        AXIS["(N)",north,\n'
+        "            ORDER[2],\n"
+        '            LENGTHUNIT["metre",1,\n'
+        '                ID["EPSG",9001]]]]'
+    )
+    crs = CRS(wkt)
+    assert crs.is_derived
+    assert crs.type_name == "Derived Projected CRS"
+
+
 def test_to_string__no_auth():
     proj = CRS("+proj=latlong +ellps=GRS80 +towgs84=-199.87,74.79,246.62")
     assert (
