@@ -2,6 +2,7 @@ import concurrent.futures
 import os
 import pickle
 from array import array
+from contextlib import nullcontext
 from functools import partial
 from glob import glob
 from itertools import permutations
@@ -19,8 +20,8 @@ from pyproj.enums import TransformDirection
 from pyproj.exceptions import ProjError
 from pyproj.transformer import AreaOfInterest, TransformerGroup
 from test.conftest import (
-    PROJ_GTE_9,
     PROJ_GTE_91,
+    PROJ_GTE_92,
     grids_available,
     proj_env,
     proj_network_env,
@@ -85,31 +86,55 @@ def test_lambert_conformal_transform():
     assert_almost_equal((Long1, Lat1, H1), (-4.6753456, 32.902199, 1341.467), decimal=5)
 
 
-def test_4d_transform():
+def test_4d_transform(scalar_and_array):
     transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
     assert_almost_equal(
         transformer.transform(
-            xx=3513638.19380, yy=778956.45250, zz=5248216.46900, tt=2008.75
+            xx=scalar_and_array(3513638.19380),
+            yy=scalar_and_array(778956.45250),
+            zz=scalar_and_array(5248216.46900),
+            tt=scalar_and_array(2008.75),
+        ),
+        (
+            scalar_and_array(3513638.1999428216),
+            scalar_and_array(778956.4532640711),
+            scalar_and_array(5248216.453456361),
+            scalar_and_array(2008.75),
         ),
-        (3513638.1999428216, 778956.4532640711, 5248216.453456361, 2008.75),
     )
 
 
-def test_2d_with_time_transform():
+def test_2d_with_time_transform(scalar_and_array):
     transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
     assert_almost_equal(
-        transformer.transform(xx=3513638.19380, yy=778956.45250, tt=2008.75),
-        (3513638.1999428216, 778956.4532640711, 2008.75),
+        transformer.transform(
+            xx=scalar_and_array(3513638.19380),
+            yy=scalar_and_array(778956.45250),
+            tt=scalar_and_array(2008.75),
+        ),
+        (
+            scalar_and_array(3513638.1999428216),
+            scalar_and_array(778956.4532640711),
+            scalar_and_array(2008.75),
+        ),
     )
 
 
-def test_4d_transform_crs_obs1():
+def test_4d_transform_crs_obs1(scalar_and_array):
     transformer = Transformer.from_proj(7789, 8401)
     assert_almost_equal(
         transformer.transform(
-            xx=3496737.2679, yy=743254.4507, zz=5264462.9620, tt=2019.0
+            xx=scalar_and_array(3496737.2679),
+            yy=scalar_and_array(743254.4507),
+            zz=scalar_and_array(5264462.9620),
+            tt=scalar_and_array(2019.0),
+        ),
+        (
+            scalar_and_array(3496737.757717311),
+            scalar_and_array(743253.9940103051),
+            scalar_and_array(5264462.701132784),
+            scalar_and_array(2019.0),
         ),
-        (3496737.757717311, 743253.9940103051, 5264462.701132784, 2019.0),
     )
 
 
@@ -123,21 +148,37 @@ def test_4d_transform_orginal_crs_obs1():
         )
 
 
-def test_4d_transform_crs_obs2():
+def test_4d_transform_crs_obs2(scalar_and_array):
     transformer = Transformer.from_proj(4896, 7930)
     assert_almost_equal(
         transformer.transform(
-            xx=3496737.2679, yy=743254.4507, zz=5264462.9620, tt=2019.0
+            xx=scalar_and_array(3496737.2679),
+            yy=scalar_and_array(743254.4507),
+            zz=scalar_and_array(5264462.9620),
+            tt=scalar_and_array(2019.0),
+        ),
+        (
+            scalar_and_array(3496737.7857162016),
+            scalar_and_array(743254.0394113371),
+            scalar_and_array(5264462.643659916),
+            scalar_and_array(2019.0),
         ),
-        (3496737.7857162016, 743254.0394113371, 5264462.643659916, 2019.0),
     )
 
 
-def test_2d_with_time_transform_crs_obs2():
+def test_2d_with_time_transform_crs_obs2(scalar_and_array):
     transformer = Transformer.from_proj(4896, 7930)
     assert_almost_equal(
-        transformer.transform(xx=3496737.2679, yy=743254.4507, tt=2019.0),
-        (3496737.4105305015, 743254.1014318303, 2019.0),
+        transformer.transform(
+            xx=scalar_and_array(3496737.2679),
+            yy=scalar_and_array(743254.4507),
+            tt=scalar_and_array(2019.0),
+        ),
+        (
+            scalar_and_array(3496737.4105305015),
+            scalar_and_array(743254.1014318303),
+            scalar_and_array(2019.0),
+        ),
     )
 
 
@@ -198,7 +239,6 @@ def test_2d_with_time_itransform_original_crs_obs2():
 
 
 def test_itransform_time_3rd_invalid():
-
     with pytest.warns(FutureWarning), pytest.raises(
         ValueError, match="'time_3rd' is only valid for 3 coordinates."
     ):
@@ -240,11 +280,13 @@ def test_transform_no_exception():
     transformer.itransform([(1.716073972, 52.658007833)], errcheck=True)
 
 
-def test_transform__out_of_bounds():
+def test_transform__out_of_bounds(scalar_and_array):
     with pytest.warns(FutureWarning):
         transformer = Transformer.from_proj("+init=epsg:4326", "+init=epsg:27700")
     with pytest.raises(pyproj.exceptions.ProjError):
-        transformer.transform(100000, 100000, errcheck=True)
+        transformer.transform(
+            scalar_and_array(100000), scalar_and_array(100000), errcheck=True
+        )
 
 
 def test_transform_radians():
@@ -302,38 +344,55 @@ def test_itransform_radians():
         )
 
 
-def test_4d_transform__inverse():
+def test_4d_transform__inverse(scalar_and_array):
     transformer = Transformer.from_pipeline("+init=ITRF2008:ITRF2000")
     assert_almost_equal(
         transformer.transform(
-            xx=3513638.1999428216,
-            yy=778956.4532640711,
-            zz=5248216.453456361,
-            tt=2008.75,
+            xx=scalar_and_array(3513638.1999428216),
+            yy=scalar_and_array(778956.4532640711),
+            zz=scalar_and_array(5248216.453456361),
+            tt=scalar_and_array(2008.75),
             direction=TransformDirection.INVERSE,
         ),
-        (3513638.19380, 778956.45250, 5248216.46900, 2008.75),
+        (
+            scalar_and_array(3513638.19380),
+            scalar_and_array(778956.45250),
+            scalar_and_array(5248216.46900),
+            scalar_and_array(2008.75),
+        ),
     )
 
 
-def test_transform_direction():
+def test_transform_direction(scalar_and_array):
     forward_transformer = Transformer.from_crs(4326, 3857)
     inverse_transformer = Transformer.from_crs(3857, 4326)
-    assert inverse_transformer.transform(
-        -33, 24, direction=TransformDirection.INVERSE
-    ) == forward_transformer.transform(-33, 24)
+    assert_array_equal(
+        inverse_transformer.transform(
+            scalar_and_array(-33),
+            scalar_and_array(24),
+            direction=TransformDirection.INVERSE,
+        ),
+        forward_transformer.transform(scalar_and_array(-33), scalar_and_array(24)),
+    )
     ident_transformer = Transformer.from_crs(4326, 3857)
-    ident_transformer.transform(-33, 24, direction=TransformDirection.IDENT) == (
-        -33,
-        24,
+    assert_array_equal(
+        ident_transformer.transform(
+            scalar_and_array(-33),
+            scalar_and_array(24),
+            direction=TransformDirection.IDENT,
+        ),
+        (scalar_and_array(-33), scalar_and_array(24)),
     )
 
 
-def test_always_xy__transformer():
+def test_always_xy__transformer(scalar_and_array):
     transformer = Transformer.from_crs(2193, 4326, always_xy=True)
     assert_almost_equal(
-        transformer.transform(1625350, 5504853),
-        (173.29964730317386, -40.60674802693758),
+        transformer.transform(scalar_and_array(1625350), scalar_and_array(5504853)),
+        (
+            scalar_and_array(173.29964730317386),
+            scalar_and_array(-40.60674802693758),
+        ),
     )
 
 
@@ -370,30 +429,52 @@ def test_transform_empty_array_xyzt(empty_array):
     )
 
 
-def test_transform_direction__string():
+def test_transform_direction__string(scalar_and_array):
     forward_transformer = Transformer.from_crs(4326, 3857)
     inverse_transformer = Transformer.from_crs(3857, 4326)
-    assert inverse_transformer.transform(
-        -33, 24, direction="INVERSE"
-    ) == forward_transformer.transform(-33, 24, direction="FORWARD")
+    assert_array_equal(
+        inverse_transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="INVERSE"
+        ),
+        forward_transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="FORWARD"
+        ),
+    )
     ident_transformer = Transformer.from_crs(4326, 3857)
-    ident_transformer.transform(-33, 24, direction="IDENT") == (-33, 24)
+    assert_array_equal(
+        ident_transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="IDENT"
+        ),
+        (scalar_and_array(-33), scalar_and_array(24)),
+    )
 
 
-def test_transform_direction__string_lowercase():
+def test_transform_direction__string_lowercase(scalar_and_array):
     forward_transformer = Transformer.from_crs(4326, 3857)
     inverse_transformer = Transformer.from_crs(3857, 4326)
-    assert inverse_transformer.transform(
-        -33, 24, direction="inverse"
-    ) == forward_transformer.transform(-33, 24, direction="forward")
+    assert_array_equal(
+        inverse_transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="inverse"
+        ),
+        forward_transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="forward"
+        ),
+    )
     ident_transformer = Transformer.from_crs(4326, 3857)
-    ident_transformer.transform(-33, 24, direction="ident") == (-33, 24)
+    assert_array_equal(
+        ident_transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="ident"
+        ),
+        (scalar_and_array(-33), scalar_and_array(24)),
+    )
 
 
-def test_transform_direction__invalid():
+def test_transform_direction__invalid(scalar_and_array):
     transformer = Transformer.from_crs(4326, 3857)
     with pytest.raises(ValueError, match="Invalid value"):
-        transformer.transform(-33, 24, direction="WHEREVER")
+        transformer.transform(
+            scalar_and_array(-33), scalar_and_array(24), direction="WHEREVER"
+        )
 
 
 def test_from_pipeline__non_transform_input():
@@ -483,48 +564,30 @@ def test_repr(from_crs, to_crs, expected_repr):
 
 @pytest.mark.grid
 def test_repr__conditional():
-    trans_repr = repr(Transformer.from_crs(4326, 26917))
-    if grids_available(
-        "ca_nrc_NA83SCRS.tif",
-        "us_noaa_FL.tif",
-        "us_noaa_MD.tif",
-        "us_noaa_TN.tif",
-        "us_noaa_gahpgn.tif",
-        "us_noaa_kyhpgn.tif",
-        "us_noaa_mihpgn.tif",
-        "us_noaa_nchpgn.tif",
-        "us_noaa_nyhpgn.tif",
-        "us_noaa_ohhpgn.tif",
-        "us_noaa_pahpgn.tif",
-        "us_noaa_schpgn.tif",
-        "us_noaa_vahpgn.tif",
-        "us_noaa_wvhpgn.tif",
-    ):
+    trans_repr = repr(Transformer.from_crs("EPSG:4326+3855", "EPSG:4979"))
+    if grids_available("us_nga_egm08_25.tif"):
         assert trans_repr == (
             "<Unknown Transformer: unknown>\n"
             "Description: unavailable until proj_trans is called\n"
             "Area of Use:\n- undefined"
         )
+    elif PROJ_GTE_92:
+        assert trans_repr == (
+            "<Unknown Transformer: noop>\n"
+            "Description: Transformation from EGM2008 height to WGS 84 "
+            "(ballpark vertical transformation, without ellipsoid height "
+            "to vertical height correction)\n"
+            "Area of Use:\n- undefined"
+        )
     else:
         assert trans_repr == (
-            "<Concatenated Operation Transformer: pipeline>\n"
-            "Description: Inverse of NAD83 to WGS 84 (1) + UTM zone 17N\n"
+            "<Other Coordinate Operation Transformer: noop>\n"
+            "Description: Transformation from EGM2008 height to WGS 84 "
+            "(ballpark vertical transformation, without ellipsoid height "
+            "to vertical height correction)\n"
             "Area of Use:\n"
-            "- name: North America - onshore and offshore: Canada - Alberta;"
-            " British Columbia; Manitoba; New Brunswick; "
-            "Newfoundland and Labrador; Northwest Territories; "
-            "Nova Scotia; Nunavut; Ontario; Prince Edward Island; Quebec; "
-            "Saskatchewan; Yukon. United States (USA) - Alabama; "
-            "Alaska (mainland); Arizona; Arkansas; California; Colorado; "
-            "Connecticut; Delaware; Florida; Georgia; Idaho; Illinois; "
-            "Indiana; Iowa; Kansas; Kentucky; Louisiana; Maine; Maryland; "
-            "Massachusetts; Michigan; Minnesota; Mississippi; Missouri; "
-            "Montana; Nebraska; Nevada; New Hampshire; New Jersey; "
-            "New Mexico; New York; North Carolina; North Dakota; Ohio; "
-            "Oklahoma; Oregon; Pennsylvania; Rhode Island; South Carolina; "
-            "South Dakota; Tennessee; Texas; Utah; Vermont; Virginia; "
-            "Washington; West Virginia; Wisconsin; Wyoming.\n"
-            "- bounds: (-172.54, 23.81, -47.74, 86.46)"
+            "- name: World\n"
+            "- bounds: (-180.0, -90.0, 180.0, 90.0)"
         )
 
 
@@ -584,6 +647,20 @@ def test_transformer__operations__scope_remarks():
     ]
 
 
+@pytest.mark.grid
+def test_transformer__only_best():
+    with nullcontext() if PROJ_GTE_92 else pytest.raises(
+        NotImplementedError, match="only_best requires PROJ 9.2"
+    ):
+        transformer = Transformer.from_crs(4326, 2964, only_best=True)
+        if not grids_available("ca_nrc_ntv2_0.tif"):
+            with pytest.raises(
+                ProjError,
+                match="Grid ca_nrc_ntv2_0.tif is not available.",
+            ):
+                transformer.transform(60, -100, errcheck=True)
+
+
 def test_transformer_group():
     trans_group = TransformerGroup(7789, 8401)
     assert len(trans_group.transformers) == 2
@@ -1286,17 +1363,21 @@ def test_transform_bounds__beyond_global_bounds():
 
 
 @pytest.mark.parametrize(
-    "input_crs,expected_bounds",
+    "input_crs,input_bounds,expected_bounds",
     [
-        ("ESRI:102036", (0, -89178008, 0, 0)),
-        ("ESRI:54026", (0, -179545824, 0, 179545824)),
+        (
+            "ESRI:102036",
+            (-180.0, -90.0, 180.0, 1.3 if PROJ_GTE_92 else 0),
+            (0, -116576599 if PROJ_GTE_92 else -89178008, 0, 0),
+        ),
+        ("ESRI:54026", (-180.0, -90.0, 180.0, 90.0), (0, -179545824, 0, 179545824)),
     ],
 )
-def test_transform_bounds__ignore_inf(input_crs, expected_bounds):
+def test_transform_bounds__ignore_inf(input_crs, input_bounds, expected_bounds):
     crs = CRS(input_crs)
     transformer = Transformer.from_crs(crs.geodetic_crs, crs, always_xy=True)
     assert_almost_equal(
-        transformer.transform_bounds(*crs.area_of_use.bounds),
+        transformer.transform_bounds(*input_bounds),
         expected_bounds,
         decimal=0,
     )
@@ -1581,30 +1662,26 @@ def test_transformer_group_authority_filter():
 
 
 def test_transformer_force_over():
-    if PROJ_GTE_9:
-        transformer = Transformer.from_crs("EPSG:4326", "EPSG:3857", force_over=True)
-        # Test a point along the equator.
-        # The same point, but in two different representations.
-        xxx, yyy = transformer.transform(0, 140)
-        xxx_over, yyy_over = transformer.transform(0, -220)
-        # Web Mercator x's between 0 and 180 longitude come out positive.
-        # But when forcing the over flag, the -220 calculation makes it flip.
-        assert xxx > 0
-        assert xxx_over < 0
-        # check it works in both directions
-        xxx_inverse, yyy_inverse = transformer.transform(
-            xxx, yyy, direction=TransformDirection.INVERSE
-        )
-        xxx_over_inverse, yyy_over_inverse = transformer.transform(
-            xxx_over, yyy_over, direction=TransformDirection.INVERSE
-        )
-        assert_almost_equal(xxx_inverse, 0)
-        assert_almost_equal(xxx_over_inverse, 0)
-        assert_almost_equal(yyy_inverse, 140)
-        assert_almost_equal(yyy_over_inverse, -220)
-    else:
-        with pytest.raises(NotImplementedError, match="force_over requires PROJ 9"):
-            Transformer.from_crs("EPSG:4326", "EPSG:3857", force_over=True)
+    transformer = Transformer.from_crs("EPSG:4326", "EPSG:3857", force_over=True)
+    # Test a point along the equator.
+    # The same point, but in two different representations.
+    xxx, yyy = transformer.transform(0, 140)
+    xxx_over, yyy_over = transformer.transform(0, -220)
+    # Web Mercator x's between 0 and 180 longitude come out positive.
+    # But when forcing the over flag, the -220 calculation makes it flip.
+    assert xxx > 0
+    assert xxx_over < 0
+    # check it works in both directions
+    xxx_inverse, yyy_inverse = transformer.transform(
+        xxx, yyy, direction=TransformDirection.INVERSE
+    )
+    xxx_over_inverse, yyy_over_inverse = transformer.transform(
+        xxx_over, yyy_over, direction=TransformDirection.INVERSE
+    )
+    assert_almost_equal(xxx_inverse, 0)
+    assert_almost_equal(xxx_over_inverse, 0)
+    assert_almost_equal(yyy_inverse, 140)
+    assert_almost_equal(yyy_over_inverse, -220)
 
 
 def test_transformer__get_last_used_operation():
